"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBodyAsString = getBodyAsString;
exports.toBrowserPath = toBrowserPath;
exports.SSEStream = void 0;

var _isStream = _interopRequireDefault(require("is-stream"));

var _getStream = _interopRequireDefault(require("get-stream"));

var _stream = _interopRequireDefault(require("stream"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param {any} body
 * @returns {Promise<string>}
 */
async function getBodyAsString(body) {
  if (Buffer.isBuffer(body)) {
    return body.toString();
  }

  if ((0, _isStream.default)(body)) {
    return (0, _getStream.default)(body);
  }

  if (typeof body !== 'string') {
    return '';
  }

  return body;
}
/**
 * Turns a file path into a path suitable for browsers, with a / as seperator.
 * @param {string} filePath
 * @returns {string}
 */


function toBrowserPath(filePath) {
  return filePath.replace(new RegExp(_path.default.sep === '\\' ? '\\\\' : _path.default.sep, 'g'), '/');
}

class SSEStream extends _stream.default.Transform {
  sendMessage(name, data = '') {
    this.write(`event: ${name}\ndata: ${data}\n\n`);
  }

  _transform(data, enc, cb) {
    this.push(data.toString('utf8'));
    cb();
  }

}

exports.SSEStream = SSEStream;